@@ -14,15 +14,16 @@ class GlobalData (BoundData):
 class ShareData (BoundData):
     fields = [
         'comment', 'path', 'guest ok', 'browseable', 'create mask', 'directory mask', 'read only',
-        'follow symlinks', 'wide links', 'fstype',
+        'follow symlinks', 'wide links', 'fstype', 'write list', 'veto files',
+        'force create mode', 'force directory mode',
     ]
     defaults = [
         '', '', 'no', 'yes', '0744', '0755', 'yes',
-        'yes', 'no', 'NTFS',
+        'yes', 'no', 'NTFS', '', '', '000', '000',
     ]
     default_values = [
         '', '', False, True, '0744', '0755', True,
-        True, False, '',
+        True, False, '', '', '', '000', '000',
     ]
 
     def template(self):
